@@ -12,7 +12,8 @@ except ImportError:
 	else: os.system(f"pip3 install cl1")
 	import cl1
 if cl1.arguments_present(["--update"]):
-	os.system(f"curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ")
+	#os.system(f"curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ")
+	os.system(f'e="/tmp/import" && rm -fr $e && curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote -o $e && chmod +x $e && bash $e')
 	sys.exit(0)
 
 # imports.
