@@ -17,12 +17,12 @@ class Key(object):
 	def edit_passphrase(self, path=None, old=None, new=None):
 
 		# checks.
-		success, response = utils.__check_parameter__(old, "old", None)
-		if not success: return response
-		success, response = utils.__check_parameter__(new, "new", None)
-		if not success: return response
-		success, response = utils.__check_parameter__(path, "path", None)
-		if not success: return response
+		response = r3sponse.check_parameters({
+			"old":old,
+			"new":new,
+			"path":path,
+		})
+		if not response["success"]: return response
 		
 		# do.
 		output = utils.__execute__(["ssh-keygen", "-p", "-P", old, "-N", new, "-f", path])
@@ -53,12 +53,12 @@ class Key(object):
 	def edit_comment(self, path=None, passphrase=None, comment=None):
 
 		# checks.
-		success, response = utils.__check_parameter__(old, "old", None)
-		if not success: return response
-		success, response = utils.__check_parameter__(passphrase, "passphrase", None)
-		if not success: return response
-		success, response = utils.__check_parameter__(comment, "comment", None)
-		if not success: return response
+		response = r3sponse.check_parameters({
+			"old":old,
+			"passphrase":passphrase,
+			"comment":comment,
+		})
+		if not response["success"]: return response
 		
 		# do.
 		output = utils.__execute__(["ssh-keygen", "-c", "-P", passphrase, "-C", comment, "-f", path])
@@ -91,8 +91,10 @@ class Key(object):
 		# checks.
 		directory = path
 		if directory[len(directory)-1] != "/": return r3sponse.error_response("The path must be a directory and end with a [/].")
-		success, response = utils.__check_parameter__(directory, "directory", None)
-		if not success: return response
+		response = r3sponse.check_parameters({
+			"directory":directory,
+		})
+		if not response["success"]: return response
 
 		# check arguments.
 		if passphrase in [None, False]:
