@@ -6,10 +6,9 @@ from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 
 def __check_os__(supported=[]):
-	response = utils.__default_response__()
 	if OS not in supported:
-		return False, r3sponse.error_response("Unsupported operating system [{}].".format(OS))
-	return True,response
+		return r3sponse.error_response(f"Unsupported operating system [{OS}].")
+	return r3sponse.success_response(f"Supported operating system [{OS}].")
 
 # the manager class.
 class SmartCards(object):
@@ -79,7 +78,6 @@ class SmartCards(object):
 	def __single_key_plugged_in__(self):
 
 		# scan.
-		response = utils.__default_response__()
 		l_response = self.scan()
 		if l_response["error"] != None: return l_response
 
@@ -126,9 +124,6 @@ class SmartCard(object):
 	# multiple keys plugged in compatible:
 	def get_info(self):
 
-		# initialize response.
-		response = utils.__default_response__()
-
 		# get info.
 		try: 
 			output = subprocess.check_output(f"ykman --device {self.serial_number} piv info", shell=True).decode().replace('  ',' ').replace('  ',' ').replace('  ',' ').lower().split('\n')
@@ -159,23 +154,20 @@ class SmartCard(object):
 	):
 		
 		# check params.
-		success, response = utils.__check_parameters__(
+		response = r3sponse.check_parameters(
 			empty_value=None,
 			parameters={
 				"pin":pin,
 				"puk":puk,
 			})
-		if not success: return response
-
-		# initialize response.
-		response = utils.__default_response__()
+		if not response["success"]: return response
 
 		# unblock.
 		output = utils.__execute_script__(f"ykman --device {self.serial_number} piv unblock-pin --puk {puk} --new-pin {pin}", shell=True)
 
 		# handle defaults.
-		success, response = self.__handle_default_output__(output)
-		if not success: return response
+		response = self.__handle_default_output__(output)
+		if not response["success"]: return response
 
 		# handle error.
 		if output != "":
@@ -193,24 +185,21 @@ class SmartCard(object):
 	):
 
 		# check params.
-		success, response = utils.__check_parameters__(
+		response = r3sponse.check_parameters(
 			empty_value=None,
 			parameters={
 				"new":new,
 				"old":old,
 			})
-		if not success: return response
-
-		# initialize response.
-		response = utils.__default_response__()
+		if not response["success"]: return response
 
 		# do.
 		command = f"ykman --device {self.serial_number} piv change-pin -P{old} -n{new}"
 		output = utils.__execute_script__(command, shell=True)
 
 		# handle defaults.
-		success, response = self.__handle_default_output__(output)
-		if not success: return response
+		response = self.__handle_default_output__(output)
+		if not response["success"]: return response
 
 		# handle success.
 		elif "New PIN set." in output: 
@@ -229,30 +218,26 @@ class SmartCard(object):
 	):
 
 		# check params.
-		success, response = utils.__check_parameters__(
+		response = r3sponse.check_parameters(
 			empty_value=None,
 			parameters={
 				"new":new,
 				"old":old,
 			})
-		if not success: return response
-
-		# initialize response.
-		response = utils.__default_response__()
+		if not response["success"]: return response
 
 		# do.
 		command = f"ykman --device {self.serial_number} piv change-puk -p{old} -n{new}"
 		output = utils.__execute_script__(command, shell=True)
 
 		# handle defaults.
-		success, response = self.__handle_default_output__(output)
-		if not success: return response
+		response = self.__handle_default_output__(output)
+		if not response["success"]: return response
 
 
 		# handle success.
 		elif "New PUK set." in output: 
 			return r3sponse.success_response(f"Successfully changed the puk of smart card [{self.serial_number}].")
-			return response
 
 		# unknown error.
 		else:
@@ -265,23 +250,20 @@ class SmartCard(object):
 	):
 
 		# check params.
-		success, response = utils.__check_parameters__(
+		response = r3sponse.check_parameters(
 			empty_value=None,
 			parameters={
 				"pin":pin,
 			})
-		if not success: return response
-
-		# initialize response.
-		response = utils.__default_response__()
+		if not response["success"]: return response
 
 		# do.
 		command = f"printf '\\n\\n' | ykman --device {self.serial_number} piv generate-key 9a public.pem --pin-policy ALWAYS  --pin {pin} --management-key 010203040506070801020304050607080102030405060708"
 		output = utils.__execute_script__(command, shell=True)
 		
 		# handle error.
-		success, response = self.__handle_default_output__(output)
-		if not success: return response
+		response = self.__handle_default_output__(output)
+		if not response["success"]: return response
 		elif output != "":
 			return r3sponse.error_response(f"Unknown error during key generation, output: [{output}].")
 
@@ -290,8 +272,8 @@ class SmartCard(object):
 		output = utils.__execute_script__(command, shell=True)
 		
 		# handle error.
-		success, response = self.__handle_default_output__(output)
-		if not success: return response
+		response = self.__handle_default_output__(output)
+		if not response["success"]: return response
 		elif output != "":
 			return r3sponse.error_response(f"Unknown error during certificate generation, output: [{output}].")
 
@@ -305,23 +287,20 @@ class SmartCard(object):
 	):
 
 		# check params.
-		success, response = utils.__check_parameters__(
+		response = r3sponse.check_parameters(
 			empty_value=None,
 			parameters={
 				"pin":pin,
 			})
-		if not success: return response
-
-		# initialize response.
-		response = utils.__default_response__()
+		if not response["success"]: return response
 
 		# do.
 		command = f'ykman --device {self.serial_number} piv change-management-key --generate --protect --pin {pin} --management-key "010203040506070801020304050607080102030405060708"'
 		output = utils.__execute_script__(command, shell=True)
 
 		# handle success.
-		success, response = self.__handle_default_output__(output)
-		if not success: return response
+		response = self.__handle_default_output__(output)
+		if not response["success"]: return response
 		elif output != "":
 			return r3sponse.error_response(f"Unknown error during management key generation, output: [{output}].")
 		else:
@@ -329,9 +308,6 @@ class SmartCard(object):
 
 		#
 	def reset_piv(self): # for when both pin & puk codes are blocked.
-		
-		# initialize response.
-		response = utils.__default_response__()
 
 		# do.
 		#output = utils.__execute_script__(f"printf 'y\\n' | ykman --device {self.serial_number} piv reset", shell=True)
@@ -339,7 +315,6 @@ class SmartCard(object):
 		
 		# handle success.
 		if "Success!" in output:
-			response["success"] = True
 			return r3sponse.success_response("Successfully resetted the smart card.")
 
 		# handle error.
@@ -353,7 +328,6 @@ class SmartCard(object):
 	):
 
 		# output.
-		response = utils.__default_response__()
 		command = f"ssh-keygen -D {self.path} -e"
 		output = utils.__execute_script__(command, shell=True, return_format="array")
 		
@@ -376,7 +350,6 @@ class SmartCard(object):
 	def check_smart_card(self):
 
 		# check.
-		response = utils.__default_response__()
 		try:
 			output = subprocess.check_output("yubico-piv-tool -aversion", shell=True).decode()
 		except:
@@ -403,17 +376,14 @@ class SmartCard(object):
 			
 		"""
 
-		# check aready converted.
-		response = utils.__default_response__()
-
 		l_response = self.check_smart_card()
 		if l_response["error"] != None: return l_response
 		if l_response["smart_card"]:
 			return r3sponse.success_response("The plugged in yubikey is already a smart cards.")
 
 		# check os.
-		success, response = __check_os__(["linux"])
-		if not success: return response
+		response = __check_os__(["linux"])
+		if not response["success"]: return response
 
 
 
@@ -469,7 +439,6 @@ class SmartCard(object):
 	):
 
 		# initialize.
-		response = utils.__default_response__()
 		if pin == None: 
 			pin = utils.__generate_pincode__(characters=6)
 		elif len(pin) != 6: return r3sponse.error_response("The pin code must be a six character integer code.")
@@ -522,24 +491,25 @@ class SmartCard(object):
 	def __handle_default_output__(self, output):
 
 		# defaults.
-		response = utils.__default_response__()
 		if isinstance(output, list): output = utils.__array_to_string__(output, joiner="\n")
 
 		# handle.
 		if "Incorrect PUK" in output:
-			return False, r3sponse.error_response(f"Provided an incorrect puk code.")
+			return r3sponse.error_response(f"Provided an incorrect puk code.")
 		elif "Incorrect PIN" in output:
 			info = self.get_info()
-			if info['success']: response["error"] = f"Provided an incorrect pin code, {info['pin_attempts']} attempts left."
-			else: response["error"] = f"Provided an incorrect pin code."
-			return False, response
+			if info['success']: 
+				return r3sponse.error_response(f"Provided an incorrect pin code, {info['pin_attempts']} attempts left.")
+			else: 
+				return r3sponse.error_response(f"Provided an incorrect pin code.")
+			return response
 		elif "PUK is blocked" in output:
 			return False, r3sponse.error_response(f"The puk code of smart card [{self.serial_number}] is blocked.")
 		elif "Error: " in output:
-			return False, r3sponse.error_response(output.split("Error: ")[1].replace('.\n', '. ').replace('\n', ''))
+			return r3sponse.error_response(output.split("Error: ")[1].replace('.\n', '. ').replace('\n', ''))
 
 		# success.
-		return True, response
+		return r3sponse.success_response("Successfully checked the output.")
 
 
 # initialized classes.
