@@ -6,16 +6,20 @@ from ssht00ls.classes.config import *
 from ssht00ls.classes.aliases import aliases
 from ssht00ls.classes.agent import agent
 import ssht00ls.classes.ssync.utils as ssync_utils 
-from ssht00ls.classes.ssync import daemon
+from ssht00ls.classes.ssync import daemons
+from ssht00ls.classes.ssh import ssh
 from ssht00ls.classes import utils
 
 # the ssync object class.
 class SSync(object):
 	def __init__(self):
 		self.utils = ssync_utils
-		if CHECKS:
-			aliases.sync()
-			daemon.sync()
+		self.daemons = daemons
+		if CHECKS and INTERACTIVE:
+			response = aliases.sync()
+			if not response["success"]: response.crash(traceback=False, json=JSON)
+			if not cl1.argument_present("--reset-cache"):
+				_ = daemons.sync()
 	def mount(self, 
 		# the local path.
 		path=None, 
@@ -31,6 +35,8 @@ class SSync(object):
 		accept_new_host_keys=True,
 		# log level.
 		log_level=0,
+		# the daemon mode.
+		mode="mount",
 	):
 
 		# checks.
@@ -40,39 +46,66 @@ class SSync(object):
 			"alias:str":alias,
 			"exclude:list":exclude,
 			"forced:bool":forced,
+			"mode:str":mode,
 			"accept_new_host_keys:bool":accept_new_host_keys, })
 		if not response["success"]: return response
-		cache_path = gfp.clean(path.split(" (d)")[0], remove_last_slash=True)
-		if not forced and os.path.exists(path):
+		if mode in ["synchronize", "sync", "synch"]: mode = "sync"
+		if mode not in ["mount", "sync"]:
+			return r3sponse.error_response(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
+		cache_path = gfp.absolute(path=gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
+		if mode in ["mount"] and not forced and os.path.exists(path):
 			return r3sponse.error_response(f"Path [{path}] already exists.")
-		elif "*mounted*" in str(cache.get(id=cache_path, group="daemons")):
+		elif self.daemons.running(cache_path):
 			return r3sponse.error_response(f"Path [{path}] is already mounted.")
 		path = gfp.clean(path=path)
 		remote = gfp.clean(path=remote)
 
 		# pull.
-		response = self.pull(
-			path=path, 
-			alias=alias, 
-			remote=remote, 
-			exclude=exclude,
-			forced=forced,
-			delete=True,
-			safe=False,
-			log_level=log_level,)
-		if not response["success"]: return response
+		if mode in ["mount"]:
+			response = self.pull(
+				path=path, 
+				alias=alias, 
+				remote=remote, 
+				exclude=exclude,
+				forced=forced,
+				delete=True,
+				safe=False,
+				log_level=log_level,)
+			if not response["success"]: return response
+		else:
+			# make sure both dirs exist in the end.
+			# raise error when both dirs do not exist at start.
+			response = ssh.utils.test_ssh_dir(path=remote, alias=alias)
+			remote_exists, local_exists = True, os.path.exists(path)
+			if not response["success"]: 
+				if "does not exist" in response["error"]:
+					remote_exists = False
+				else:
+					return response
+			if not remote_exists and not local_exists:
+				return r3sponse.error_response(f"Both local and remote directories {path} & {alias}:{remote} do not exist.")
+			if not local_exists:
+				os.system(f"mkdir -p {path}")
+				if not os.path.exists(path): 
+					return r3sponse.error_response(f"Failed to create directory {path}.")
+			if not remote_exists:
+				response = ssh.utils.test_ssh_dir(path=remote, alias=alias, create=True)
+				if not response["success"]: 
+					return r3sponse.error_response(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
 
 		# start daemon.
-		cache.set(id=cache_path, group="daemons", data="*mounted*")
+		cache.set(id=cache_path, group="daemons", data=f"*running* (timestamp={Formats.Date().seconds_timestamp})")
 		self.set_mounted_icon(path)
-		#status = cache.get(id=cache_path, group="daemons")
-		#if status != "*mounted*":
-		#	return r3sponse.error_response(f"Failed to set the {path} daemon status.")
-		response =  self.daemon(alias=alias, path=path, remote=remote, start=True)
+		if not self.daemons.running(cache_path):
+			return r3sponse.error_response(f"Failed to set the {path} daemon status.")
+		response =  self.daemon(alias=alias, path=path, remote=remote, start=True, mode=mode)
 		if not response.success: return response
 
 		# handler.
-		return r3sponse.success_response(f"Successfully mounted [{alias}:{remote}] ==> [{path}].")
+		if mode == "sync":
+			return r3sponse.success_response(f"Successfully synchronized {alias}:{remote} to {path}.")
+		else:
+			return r3sponse.success_response(f"Successfully mounted {alias}:{remote} to {path}.")
 
 		#
 	def unmount(self, 
@@ -93,19 +126,18 @@ class SSync(object):
 			"sudo:bool":sudo, })
 		if not response["success"]: return response
 		path = gfp.clean(path)
-		cache_path = gfp.clean(path.split(" (d)")[0], remove_last_slash=True)
-		mounted = "*mounted*" in str(cache.get(id=cache_path, group="daemons"))
-		if not mounted:
+		cache_path = gfp.absolute(gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
+		if not self.daemons.running(cache_path):
 			if not os.path.exists(path):
 				return r3sponse.error_response(f"Path [{path}] does not exist.")
 			elif not os.path.isdir(path):
 				return r3sponse.error_response(f"Path [{path}] is not a directory.")
 			status = str(cache.get(id=cache_path, group="daemons"))
-			if "*mounted*" not in str(status):
+			if not self.daemons.running(cache_path):
 				return r3sponse.error_response(f"Path [{path}] is not mounted (status: {status}).")
 
 		# wait for daemon stop.
-		response = self.stop_daemon(path=path)
+		response = self.daemons.stop(path=path)
 		if not success: return response
 
 		# handler.
@@ -140,9 +172,9 @@ class SSync(object):
 				# tests.
 				response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 				if not response["success"]: return response
-				response = utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
+				response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 				if not response["success"]: return response
-				response = utils.test_ssh_path(alias=alias, path=path, accept_new_host_keys=accept_new_host_keys)
+				response = ssh.utils.test_ssh_path(alias=alias, path=path, accept_new_host_keys=accept_new_host_keys)
 				if not response["success"]: return response
 
 			# index.
@@ -346,7 +378,7 @@ class SSync(object):
 			log_level=log_level,
 			# get the command in str.
 			command=command,)
-	# initialize a mounted daemon.
+	# initialize a daemon.
 	def daemon(self, 
 		# the ssh alias.
 		alias=None, 
@@ -362,11 +394,13 @@ class SSync(object):
 		log_level=syst3m.defaults.log_level(default=-1),
 		# sandbox (do not delete any files).
 		sandbox=False,
+		# overwrite sleeptime.
+		sleeptime=SSYNC_DAEMON_SLEEPTIME,
 		# serialized.
 		serialized={},
 	):
 		if serialized != {}:
-			alias, remote, path, start, mode, log_level, sandbox = Files.Dictionary(path=False, dictionary=serialized).unpack({
+			alias, remote, path, start, mode, log_level, sandbox, sleeptime = Files.Dictionary(path=False, dictionary=serialized).unpack({
 				"alias":None,
 				"remote":None,
 				"path":None,
@@ -374,13 +408,14 @@ class SSync(object):
 				"mode":"mount",
 				"log_level":syst3m.defaults.log_level(default=-1),
 				"sandbox":False,
+				"sleeptime":SSYNC_DAEMON_SLEEPTIME,
 			})
 		if mode in ["synchronize", "sync", "synch"]: mode = "sync"
 		if mode not in ["mount", "sync"]:
 			return r3sponse.error_response(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
 		path = gfp.clean(path)
 		remote = gfp.clean(remote)
-		_daemon_ = daemon.Daemon({
+		_daemon_ = daemons.Daemon({
 			"alias":alias,
 			"remote":remote,
 			"path":path,
@@ -389,14 +424,12 @@ class SSync(object):
 			"sandbox":sandbox,
 			"ssync":self,
 			"utils":self.utils,
-			"sleeptime":0.25,
+			"sleeptime":sleeptime,
 		})
 		if start: webserver.start_daemon(_daemon_, group="daemons", id=_daemon_.id)
 		return r3sponse.success_response("Successfully initialized the daemon", {
 			"daemon":_daemon_,
 		})
-	def stop_daemon(self, path, timeout=60, sleeptime=1):
-		return daemon.stop_daemon(path, timeout=timeout, sleeptime=sleeptime)
 	
 # initialized objects.
 ssync = SSync()
