@@ -6,19 +6,21 @@ import os
 from fil3s import Files, Formats, gfp
 from r3sponse import r3sponse
 from ssht00ls.classes.config import * 
-from ssht00ls.classes import utils
+from ssht00ls.classes.ssh import ssh
+from ssht00ls.classes.ssync.index import index
+from ssht00ls.classes.ssh.utils import execute
 
 # settings.
-INCLUDE = ['.git', 'dist', "'*.egg-info'"]
+INCLUDE = []# '.git', 'dist', "'*.egg-info'"
 EXCLUDE = ['__pycache__', '.DS_Store']
 
 # serialize path.
 def serialize_path(path, append_last_slash=False):
 	# keep in mind the file is saved by python and then executed.
-	list = []
+	array = []
 	for i in [" ","!","?","@","#","$","&","(",")","[","]","{","}"]:
-		list.append([i, f"\\{i}"],)
-	for x,y in list+[
+		array.append([i, f"\\{i}"],)
+	for x,y in array+[
 		#[" ", "\\ "],
 	]:
 		path = path.replace(x,y)
@@ -27,20 +29,19 @@ def serialize_path(path, append_last_slash=False):
 		else: break
 	return path
 
-# index.
-def index(path):
-	index, dir, ids = Files.Dictionary(path=False, dictionary={}), Files.Directory(path=path), []
-	for _path_ in dir.paths(recursive=True, files_only=True, banned=[gfp.clean(f"{path}/Icon\r")], banned_names=[".DS_Store", "__pycache__"]):
-		if _path_ not in ids and "/__pycache__/" not in path and "/.DS_Store" not in path: 
-			index[_path_] = gfp.mtime(path=_path_, format="seconds")
-			ids.append(_path_)
-	for _path_ in dir.paths(recursive=True, dirs_only=True, banned=[gfp.clean(f"{path}/Icon\r")], banned_names=[".DS_Store", "__pycache__"]):
-		id = _path_+" (d)"
-		if os.listdir(_path_) == []: id += " (e)"
-		if id not in ids and "/__pycache__/" not in path and "/.DS_Store" not in path: 
-			index[id] = gfp.mtime(path=_path_, format="seconds")
-			ids.append(id)
-	return index.sort(alphabetical=True)
+# get the size of a dir.
+def size(path, alias=None, log_level=0):
+	if alias == None:
+		return r3sponse.success_response(f"Successfully retrieved the size of {path}.", {
+			"size":Formats.FilePath(path).size(mode="MB"),
+		})
+	else:
+		return execute(
+			command=f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' python3 /usr/local/lib/ssht00ls/classes/utils/size.py {path} ' '""",
+			message=f"Successfully retrieved the size of {alias}:{path}.",
+			error=f"Failed to retrieve the size of {alias}:{path}.",
+			log_level=log_level,
+			serialize=True,)
 
 # pull.
 def pull(
@@ -94,21 +95,21 @@ def pull(
 		# tests.
 		#response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 		#if not response["success"]: return response
-		response = utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
-		response = utils.test_ssh_path(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_ssh_path(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
 
 		# dir.
 		if directory == None: 
-			response = utils.test_ssh_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
+			response = ssh.utils.test_ssh_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
 			if not response.success and "not a directory" not in response.error: return response
 			elif response.success:
 				directory = True
 			else: directory = False
 			tested = True
 		elif directory:
-			response = utils.test_ssh_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
+			response = ssh.utils.test_ssh_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
 			if not response.success: return response
 			tested = True
 
@@ -199,9 +200,9 @@ def push(
 		# tests.
 		#response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 		#if not response["success"]: return response
-		response = utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
-		response = utils.test_ssh_path(alias=alias, path=Formats.FilePath(remote).base(), accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_ssh_path(alias=alias, path=Formats.FilePath(remote).base(), accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
 
 		# dir.
@@ -212,7 +213,7 @@ def push(
 	# check remote base.
 	# must be excluded from the checks == False.
 	base = Formats.FilePath(remote).base(back=1)
-	response = utils.test_ssh_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
+	response = ssh.utils.test_ssh_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
 	if not response.success: return response
 	if response.created and log_level >= 3: print(f"Created remote directory {base}.")
 
@@ -238,68 +239,6 @@ def push(
 
 	#
 
-# execute.
-def execute( 
-	# the command in str.
-	command="ls",
-	# the success message.
-	message="Successfully executed the specified command.",
-	# the error message.
-	error="Failed to execute the specified command.",
-	# loader message.
-	loader=None,
-	# serialize to json (overwrites message & error).
-	serialize=False,
-	# get the output.
-	get_output=False,
-	# the log level.
-	log_level=0,
-):
-
-	# execute.
-	if log_level >= 6: print(command)
-	if loader != None:
-		loader = syst3m.console.Loader(loader, interactive=INTERACTIVE)
-	#output = syst3m.utils.__execute_script__(command)
-	path = f"/tmp/tmp_script_{Formats.String('').generate()}"
-	Files.save(path, command)
-	#try:
-	#	output = subprocess.check_output(["sh", path]).decode()
-	try:
-		output = subprocess.check_output(["sh", path]).decode()
-	except subprocess.CalledProcessError as e:
-		#if " exit status " in str(e.output):
-		#	return r3sponse.error_response(f"Failed to execute command [{command}], (exit status: {str(e.output).split(' exit status ')[1].split('.')[0].split(' ')[0]}).")
-		#else:
-		#	return r3sponse.error_response(f"Failed to execute command [{command}].")
-		return r3sponse.error_response(f"Failed to execute command [{command}], (output: {e.output}), (error: {e}).")
-	Files.delete(path)
-	if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
-
-	# handler.
-	response = utils.check_errors(output)
-	if not response.success:
-		if loader != None: loader.stop(success=False)
-		return response
-		#print(output)
-		#return r3sponse.error_response(error)
-	else:
-		if loader != None: loader.stop()
-		if serialize:
-			try: response = r3sponse.serialize(output)
-			except Exception as e: 
-				return r3sponse.error_response(f"Failed to serialize output: {output}")
-			return response
-		else:
-			if get_output:
-				return r3sponse.success_response(message, {
-					"output":output,
-				})
-			else:
-				return r3sponse.success_response(message)
-
-	#
-
 # main.
 if __name__ == "__main__":
 	a=1
